@@ -8,12 +8,40 @@ use inflector::Inflector;
 use rust_embed::RustEmbed;
 use std::path::PathBuf;
 use walkdir::WalkDir;
+use update_informer::{registry, Check};
 use crate::BackendFramework;
 
 #[derive(RustEmbed)]
 #[folder = "template"]
 struct Asset;
 
+// const CRA_CARGO_TOML: &'static str = include_str!(concat!(env!("CARGO_MANIFEST_DIR"), "/../create-rust-app/Cargo.toml"));
+// fn get_current_cra_lib_version() -> String {
+//     let err_message = &format!("Could not parse create-rust-app toml! Here it is:\n================\n{:#?}", CRA_CARGO_TOML);
+//
+//     let cargo_toml = CRA_CARGO_TOML.to_string();
+//     let cargo_toml = cargo_toml.parse::<toml::Value>()
+//         .expect(err_message);
+//     let cargo_toml = cargo_toml
+//         .as_table()
+//         .expect(err_message);
+//
+//     let package_table = cargo_toml.get("package")
+//         .expect(err_message)
+//         .as_table()
+//         .expect(err_message);
+//
+//     let version = package_table.get("version")
+//         .expect(err_message)
+//         .as_str()
+//         .expect(err_message);
+//
+//     version.to_string()
+// }
+fn get_current_cra_lib_version() -> String {
+    "6.0.0".to_string()
+}
+
 fn add_bins_to_cargo_toml(project_dir: &std::path::PathBuf) -> Result<(), std::io::Error> {
     let mut path = std::path::PathBuf::from(project_dir);
     path.push("Cargo.toml");
@@ -59,6 +87,9 @@ path = ".cargo/bin/tsync.rs"
 [[bin]]
 name = "{project_name}"
 path = "backend/main.rs"
+
+[profile.dev]
+debug-assertions=true
 "#,
         project_name = project_name
     );
@@ -212,12 +243,12 @@ pub fn create(project_name: &str, creation_options: CreationOptions) -> Result<(
         }
     }
     add_dependency(&project_dir, "futures-util", r#"futures-util = "0.3.21""#)?;
-    add_dependency(&project_dir, "create-rust-app", &format!("create-rust-app = {{version=\"5.1.0\"{enabled_features}}}", enabled_features=enabled_features))?;
     add_dependency(&project_dir, "serde", r#"serde = { version = "1.0.133", features = ["derive"] }"#)?;
     add_dependency(&project_dir, "serde_json", r#"serde_json = "1.0.79""#)?;
     add_dependency(&project_dir, "chrono", r#"chrono = { version = "0.4.19", features = ["serde"] }"#)?;
     add_dependency(&project_dir, "tsync", r#"tsync = "1.2.1""#)?;
     add_dependency(&project_dir, "diesel", r#"diesel = { version="1.4.8", default-features = false, features = ["postgres", "r2d2", "chrono"] }"#)?;
+    add_dependency(&project_dir, "create-rust-app", &format!("create-rust-app = {{version=\"{version}\"{enabled_features}}}", version= get_current_cra_lib_version(), enabled_features=enabled_features))?;
 
     /*
         Populate with project files
@@ -379,3 +410,16 @@ pub fn create_resource(backend: BackendFramework, resource_name: &str) -> Result
 
     Ok(())
 }
+
+pub fn check_cli_version() -> Result<()>{
+  let name = env!("CARGO_PKG_NAME");
+  let version = env!("CARGO_PKG_VERSION");
+  let informer = update_informer::new(registry::Crates, name, version);
+  if let Some(new_version) = informer.check_version().ok().flatten()  {
+    logger::message(&style(&format!("You are running `{name}` v{version}, which is behind the latest release ({new_version}).")).yellow().to_string());
+    logger::message(&format!("If you want to update, try: {}", style("cargo install --force create-rust-app_cli").yellow()));
+  } else {
+    logger::message(&format!("You are running the latest version of {name} ({version})!"));
+  }
+  Ok(())
+}
